================
Predefined Field
================

A PredefinedField object stores the non-propagating data of a predefined field as well as a number of instances of the corresponding PredefinedFieldState object. The PredefinedFieldState object stores the propagating data of the predefined field in a single step. A specific type of PredefinedField object and a specific type of PredefinedFieldState object are designed for each type of predefined field. Instances of the PredefinedFieldState object are created and deleted internally by its corresponding PredefinedField object.


Create predefined fields
------------------------

.. autoclass:: abaqus.PredefinedField.PredefinedFieldModel.PredefinedFieldModel
    :members:
    :special-members: __init__

Classes
-------

Field
~~~~~

.. autoclass:: abaqus.PredefinedField.Field.Field
    :members:
    :special-members: __init__

    .. autoclasstoc::

FieldState
~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.FieldState.FieldState
    :members:
    :special-members: __init__

    .. autoclasstoc::

PredefinedField
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.PredefinedField.PredefinedField
    :members:
    :special-members: __init__

    .. autoclasstoc::

PredefinedFieldState
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.PredefinedFieldState.PredefinedFieldState
    :members:
    :special-members: __init__

    .. autoclasstoc::

FluidCavityPressure
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.FluidCavityPressure.FluidCavityPressure
    :members:
    :special-members: __init__

    .. autoclasstoc::

IMAField
~~~~~~~~

.. autoclass:: abaqus.PredefinedField.IMAField.IMAField
    :members:
    :special-members: __init__

    .. autoclasstoc::

IMARegion
~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.IMARegion.IMARegion
    :members:
    :special-members: __init__

    .. autoclasstoc::

InitialState
~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.InitialState.InitialState
    :members:
    :special-members: __init__

    .. autoclasstoc::

KinematicHardening
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.KinematicHardening.KinematicHardening
    :members:
    :special-members: __init__

    .. autoclasstoc::

MaterialAssignment
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.MaterialAssignment.MaterialAssignment
    :members:
    :special-members: __init__

    .. autoclasstoc::

Temperature
~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.Temperature.Temperature
    :members:
    :special-members: __init__

    .. autoclasstoc::

TemperatureState
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.TemperatureState.TemperatureState
    :members:
    :special-members: __init__

    .. autoclasstoc::

TiffOptions
~~~~~~~~~~~

.. autoclass:: abaqus.PredefinedField.TiffOptions.TiffOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

Velocity
~~~~~~~~

.. autoclass:: abaqus.PredefinedField.Velocity.Velocity
    :members:
    :special-members: __init__

    .. autoclasstoc::

